import os
import pandas as pd
import matplotlib.pyplot as plt
import datetime
import numpy as np

BASEPATH = # insert your data file path here

#%% define source csv file
source_datafile = os.path.join(BASEPATH, 'processed', 'covid_processed.csv')

#%% load source file
df = pd.read_csv(source_datafile, index_col=0)

"""### CONSENT """

# Keep only participants that provided Consent and drop the column
df = df[df.consent == 'Yes']
df = df.drop('consent', axis=1)

# Print the number of removed participants and the number of the remaining participants
print('removed', 2276-df.shape[0])
print('remaining', df.shape[0])

"""### COMPLETE"""

# Keep only completed surveys
df = df[(df.Progress >= 99)]

# Remove column of progress
df = df.drop(['Progress'], axis = 1)

# Print the number of removed participants and the number of the remaining participants
print('removed', 2244-df.shape[0])
print('remaining', df.shape[0])

"""### SAME DAY"""

# Process date format
df.StartDate = [datetime.datetime.strptime(x,'%Y-%m-%d %H:%M:%S' ).date() if type(x) == str else x for x in df.StartDate ]
df.EndDate = [datetime.datetime.strptime(x,'%Y-%m-%d %H:%M:%S' ).date() if type(x) == str else x for x in df.EndDate ]

# Keep only participants who started and completed the survey within the same day
df = df[(df.StartDate == df.EndDate)]

# Because they are now identical, remove EndDate and rename StartDate
df = df.drop(['EndDate'], axis = 1)
df.rename(columns={'StartDate':'Date'}, inplace=True)

# Print the number of removed participants and the number of the remaining participants
print('removed', 1532-df.shape[0])
print('remaining', df.shape[0])

"""### RESIDENTS"""

# Keep only participants who completed the survey from their country of residence
df = df[(df.country2 == df.country1)]

# Because they are now identical, remove column of country2
df = df.drop(['country2'], axis = 1)

# Print the number of removed participants and the number of the remaining participants
print('removed', 1456-df.shape[0])
print('remaining', df.shape[0])

"""### REMOVE NA"""

# Remove participants with NA values in the columns of interest
selected_cols = ['ID','country1', 'Gender', 'LoneTot', 'CASEStot', 'PHQtot', 'MildActDiff', 'MildActTimeDiff', 'GADtot',
                 'SleepTot', 'BeliefTot', 'ModActDiff', 'CHAOStot', 'spq22', 'RPQtot', 'Date']

for col in selected_cols:
    df = df[df[col].notna()]

# Print the number of removed participants and the number of the remaining participants
print('removed', 1324-df.shape[0])
print('remaining', df.shape[0])

# Select the columns of interest
selected_cols = ['ID', 'age_year','country1', 'Gender', 'LoneTot', 'CASEStot', 'PHQtot', 'MildActDiff', 'MildActTimeDiff', 'GADtot',
                 'SleepTot', 'BeliefTot', 'ModActDiff', 'CHAOStot', 'spq22', 'RPQtot', 'Date']

df = df.reindex(columns = selected_cols)

# Define name of the dataset
DATASETNAME = 'UK_dataUCL.csv'

# Create folder if it does not exist
OUTDIR = os.path.join(BASEPATH, 'datasets', 'wave1')
os.makedirs(OUTDIR, exist_ok=True)

# Save dataset
df.to_csv(os.path.join(OUTDIR, DATASETNAME))
