import os
import pandas as pd
import matplotlib.pyplot as plt
import datetime
import numpy as np

BASEPATH = # insert your data file path here

# define source csv file
source_datafile = os.path.join(BASEPATH, 'datasets', 'wave1', 'UK_dataUCL.csv')

# load source file
df = pd.read_csv(source_datafile, index_col=0)

# Select sample from the UK and reset index
df_UK = df[(df.country1 == 'United Kingdom of Great Britain and Northern Ireland')]
df_UK = df_UK.reset_index(drop=True)

"""### COMPUTE LABELS: UK"""

# Define name of the dataset
DATASETNAME = 'Week_UK'

# Create folder if it does not exist
OUTDIR = os.path.join(BASEPATH, 'datasets', 'wave1', DATASETNAME)
os.makedirs(OUTDIR, exist_ok=True)

# Process 'Date' to obtain days into lockdown
dates = df_UK['Date']

# Converts date string of the first day to date-time format
t0 = pd.to_datetime(dates[0])

# Compute the difference between each date and t0

days = [(pd.to_datetime(x) - t0)/ np.timedelta64(1, 'D') + 25 for x in dates]

# Create new col with the computed days

df_UK['days'] = days

label= df_UK['days']//7

df_UK['label'] = label

#remove days and Date as they have been used to compute the label
df_UK.drop('days', axis = 1, inplace=True)
df_UK.drop('Date', axis = 1, inplace=True)

#remove data after week 9
df_UK.query('label < 10', inplace=True)

#%% save dataset
df_UK.to_csv(os.path.join(OUTDIR, 'data.csv'))
