import os
import pandas as pd
import matplotlib.pyplot as plt
import datetime
import numpy as np

BASEPATH = # insert your data file path here
PROCESSED = BASEPATH + 'processed/'

# Load data
df = pd.read_csv(PROCESSED + 'wave2_processed.csv', index_col=0)

"""### Complete"""

#exclude non complete
df = df[(df.Progress >= 99)]

#remove column of progress
df = df.drop(['Progress'], axis = 1)

# check removed and remaining participants
print('removed', 2280-df.shape[0])
print('remaining', df.shape[0])

"""### SAME DAY"""

# Process date format
df.StartDate = [datetime.datetime.strptime(x,'%Y-%m-%d %H:%M:%S' ).date() if type(x) == str else x for x in df.StartDate ]
df.EndDate = [datetime.datetime.strptime(x,'%Y-%m-%d %H:%M:%S' ).date() if type(x) == str else x for x in df.EndDate ]

# Keep only participants who started and completed the survey within the same day

df = df[(df.StartDate == df.EndDate)]

#because they are now identical, remove EndDate and rename StartDate
df = df.drop(['EndDate'], axis = 1)
df.rename(columns={'StartDate':'Date'}, inplace=True)

# check removed and remaining participants
print('removed', 939-df.shape[0])
print('remaining', df.shape[0])

"""### RESIDUALS"""

# Keep only participants who completed the survey from their country of residence
df = df[(df.country2 == df.country1)]

# Because they are now identical, remove column of country2
df = df.drop(['country2'], axis = 1)

# check removed and remaining participants
print('removed', 733-df.shape[0])
print('remaining', df.shape[0])

"""### REMOVE NA"""

# Remove participants with NA values in the columns of interest
selected_cols = ['country1', 'Gender', 'LoneTot', 'CASEStot', 'PHQtot', 'MildActDiff', 'MildActTimeDiff', 'GADtot',
                 'SleepTot', 'BeliefTot', 'ModActDiff', 'CHAOStot', 'spq22', 'RPQtot', 'Date']
for col in selected_cols:
    df = df[df[col].notna()]

# Select the columns of interest
selected_cols = ['ID', 'age_year','country1', 'Gender', 'LoneTot', 'CASEStot', 'PHQtot', 'MildActDiff', 'MildActTimeDiff', 'GADtot',
                 'SleepTot', 'BeliefTot', 'ModActDiff', 'CHAOStot', 'spq22', 'RPQtot', 'Date']

df = df.reindex(columns = selected_cols)

# check removed and remaining participants
print('removed', 690-df.shape[0])
print('remaining', df.shape[0])

#%% define name of the dataset
DATASETNAME = 'df_ParticipantsExcluded'

#create folder if it does not exist
OUTDIR = os.path.join(BASEPATH, 'datasets', 'wave2', DATASETNAME)
os.makedirs(OUTDIR, exist_ok=True)

#%% save dataset
df.to_csv(os.path.join(OUTDIR, 'data.csv'))
