import os
import pandas as pd
import matplotlib.pyplot as plt
import datetime
import numpy as np
import statistics

BASEPATH = # insert your data file path here

#%% define source csv file
source_datafile = os.path.join(BASEPATH, 'datasets', 'wave2', 'df_ParticipantsExcluded', 'data.csv')

#%% load source file
df = pd.read_csv(source_datafile, index_col=0)

# Select participants from the UK
df_UK = df[(df.country1 == 'United Kingdom of Great Britain and Northern Ireland')]

# reset index for the UK dataset
df_UK = df_UK.reset_index(drop=True)

"""### COMPUTE LABELS"""

#%% define name of the dataset
DATASETNAME = 'Week_UK'

#create folder if it does not exist
OUTDIR = os.path.join(BASEPATH, 'datasets', 'wave2', DATASETNAME)
os.makedirs(OUTDIR, exist_ok=True)

#%% sorting the dataframe by date
df_UK = df_UK.sort_values('Date', ascending=True)

#%% process 'Date' to obtain days into lockdown
dates = df_UK['Date']

#converts date string of the first day to date-time format
t0 = pd.to_datetime(dates.values[0])

#compute the difference between each date and t0 and compute distance from 5 nov 2020 and t0
days = [(pd.to_datetime(x) - t0)/ np.timedelta64(1, 'D') - 16 for x in dates]

#create new col with the computed days
df_UK['days'] = days

label= df_UK['days']//7

df_UK['label'] = label

#%%
#remove days and Date as they have been used to compute the label
df_UK.drop('days', axis = 1, inplace=True)
df_UK.drop('Date', axis = 1, inplace=True)

#%% save dataset
df_UK.to_csv(os.path.join(OUTDIR, 'data.csv'))
