This is the README file for the scripts of the preprint "Self-Perceived
Loneliness and Depression During the COVID-19 Pandemic: a Two-Wave Replication
Study" by Carollo et al. (2022)

Abstract: Background: The global COVID-19 pandemic has forced countries to
impose strict lockdown restrictions and mandatory stay-at-home orders with
varying impacts on individual’s health. Combining a data-driven machine learning
paradigm and a statistical approach, our previous paper documented a U-shaped
pattern in levels of self-perceived loneliness in both the UK and Greek
populations during the first lockdown (17 April to 17 July 2020). The current
paper aimed to test the robustness of these results by focusing on data
from the first and second lockdown waves in the UK. Methods: We tested a) the
impact of the chosen model on the identification of the most time-sensitive
variable in the period spent in lockdown. Two new machine learning
models - namely, support vector regressor (SVR) and multiple linear regressor
(MLR) were adopted to identify the most time-sensitive variable in the UK
dataset from wave 1 (n = 435). In the second part of the study, we tested
b) whether the pattern of self-perceived loneliness found in the first UK
national lockdown was generalizable to the second wave of UK lockdown
(17 October 2020 to 31 January 2021). To do so, data from wave 2 of the UK
lockdown (n = 263) was used to conduct a graphical and statistical inspection
of the week-by-week distribution of self-perceived loneliness scores. Results:
In both SVR and MLR models, depressive symptoms resulted to be the most
time-sensitive variable during the lockdown period. Statistical analysis of
depressive symptoms by week of lockdown resulted in a U-shaped pattern
between week 3 to 7 of wave 1 of the UK national lockdown. Furthermore,
despite the sample size by week in wave 2 was too small for having a meaningful
statistical insight, a qualitative and descriptive approach was adopted and
a graphical U-shaped distribution between week 3 and 9 of lockdown was
observed. Conclusions: Consistent with past studies, study findings suggest
that self-perceived loneliness and depressive symptoms may be two of the
most relevant symptoms to address when imposing lockdown restrictions.

In particular, the folder includes the scripts for the pre-processing,
training, and post-processing phases of the research.

==== PRE-PROCESSING WAVE 1 DATASET ====
- "01_preprocessingWave1.py": this file include the pre-processing of the
variables of interest for wave 1 data;
- "02_participantsexcludedWave1.py": this file include the script adopted to
implement the exclusion criteria of the study for wave 1 data;
- "03_countryselectionWave1.py": this file include the script to select the UK
dataset for wave 1.

==== PRE-PROCESSING WAVE 2 DATASET ====
- "04_preprocessingWave1.py": this file include the pre-processing of the
variables of interest for wave 2 data;
- "05_participantsexcludedWave1.py": this file include the script adopted to
implement the exclusion criteria of the study for wave 2 data;
- "06_countryselectionWave1.py": this file include the script to select the UK
dataset for wave 2.

==== TRAINING ====
- "07_MLR.py": this file includes the script to run the multiple regression
model;
- "08_SVM.py": this file includes the script to run the support vector regression
model.

==== POST-PROCESSING: STATISTICAL ANALYSIS ====
- "09_KruskalWallisTests.py": this file includes the script to run the multipair
and the pairwise Kruskal-Wallis tests.
